pub fn extract_web_vital_metrics(span: &SpanV2) -> Option<Vec<TraceMetric>>Expand description
Extract any web vitals metrics for the supplied v2 span. Bad or missing metrics will be silently dropped.
pub fn extract_web_vital_metrics(span: &SpanV2) -> Option<Vec<TraceMetric>>Extract any web vitals metrics for the supplied v2 span. Bad or missing metrics will be silently dropped.